% Auto-generated chapter 16 for abudawud
% Hadiths in this chapter: 56

\hadithdefcmd{abudawud}{2788}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ، ح وَحَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا بِشْرٌ، عَنْ عَبْدِ اللَّهِ بْنِ عَوْنٍ، عَنْ عَامِرٍ أَبِي رَمْلَةَ، قَالَ أَخْبَرَنَا مِخْنَفُ بْنُ سُلَيْمٍ، قَالَ وَنَحْنُ وُقُوفٌ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِعَرَفَاتٍ قَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّ عَلَى كُلِّ أَهْلِ بَيْتٍ فِي كُلِّ عَامٍ أُضْحِيَةً وَعَتِيرَةً أَتَدْرُونَ مَا الْعَتِيرَةُ هَذِهِ الَّتِي يَقُولُ النَّاسُ الرَّجَبِيَّةُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْعَتِيرَةُ مَنْسُوخَةٌ هَذَا خَبَرٌ مَنْسُوخٌ ‏.‏\hadithno{2788}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mikhnaf ibn Sulaym: We were staying with the Messenger of Allah (ﷺ) at Arafat; he said: O people, every family must offer a sacrifice and an atirah. Do you know what the atirah is? It is what you call the Rajab sacrifice. Abu Dawud said: 'Atirah has been abrogated, and this tradition is an abrogated one}}
\hadithdefcmd{abudawud}{2789}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، حَدَّثَنِي عَيَّاشُ بْنُ عَبَّاسٍ الْقِتْبَانِيُّ، عَنْ عِيسَى بْنِ هِلاَلٍ الصَّدَفِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ أُمِرْتُ بِيَوْمِ الأَضْحَى عِيدًا جَعَلَهُ اللَّهُ عَزَّ وَجَلَّ لِهَذِهِ الأُمَّةِ ‏"‏ ‏.‏ قَالَ الرَّجُلُ أَرَأَيْتَ إِنْ لَمْ أَجِدْ إِلاَّ أُضْحِيَةً أُنْثَى أَفَأُضَحِّي بِهَا قَالَ ‏"‏ لاَ وَلَكِنْ تَأْخُذُ مِنْ شَعْرِكَ وَأَظْفَارِكَ وَتَقُصُّ شَارِبَكَ وَتَحْلِقُ عَانَتَكَ فَتِلْكَ تَمَامُ أُضْحِيَتِكَ عِنْدَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2789}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: I have been commanded to celebrate festival ('Id) on the day of sacrifice, which Allah, Most High, has appointed for this community. A man said: If I do not find except a she-goat or a she-camel borrowed for milk or other benefits, should I sacrifice it? He said: No, but you should clip your hair , and nails, trim your moustaches, and shave your pubes. This is all your sacrifice in the eyes of Allah, Most High}}
\hadithdefcmd{abudawud}{2790}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي الْحَسْنَاءِ، عَنِ الْحَكَمِ، عَنْ حَنَشٍ، قَالَ رَأَيْتُ عَلِيًّا يُضَحِّي بِكَبْشَيْنِ فَقُلْتُ مَا هَذَا فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَوْصَانِي أَنْ أُضَحِّيَ عَنْهُ فَأَنَا أُضَحِّي عَنْهُ ‏.‏\hadithno{2790}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hanash: I saw Ali sacrificing two rams; so I asked him: What is this? He replied. The Messenger of Allah (ﷺ) enjoined upon me to sacrifice on his behalf, so that is what I am doing}}
\hadithdefcmd{abudawud}{2791}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، حَدَّثَنَا عَمْرُو بْنُ مُسْلِمٍ اللَّيْثِيُّ، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ سَمِعْتُ أُمَّ سَلَمَةَ، تَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ لَهُ ذِبْحٌ يَذْبَحُهُ فَإِذَا أَهَلَّ هِلاَلُ ذِي الْحِجَّةِ فَلاَ يَأْخُذَنَّ مِنْ شَعْرِهِ وَلاَ مِنْ أَظْفَارِهِ شَيْئًا حَتَّى يُضَحِّيَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ اخْتَلَفُوا عَلَى مَالِكٍ وَعَلَى مُحَمَّدِ بْنِ عَمْرٍو فِي عَمْرِو بْنِ مُسْلِمٍ قَالَ بَعْضُهُمْ عُمَرُ وَأَكْثَرُهُمْ قَالَ عَمْرٌو ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ عَمْرُو بْنُ مُسْلِمِ بْنِ أُكَيْمَةَ اللَّيْثِيُّ الْجُنْدَعِيُّ ‏.‏\hadithno{2791}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim (1977)}\hadithtrans{Narrated Umm Salamah: The Prophet (ﷺ) as saying: If anyone has sacrificial animal and intends to sacrifice it, and he sights the new moon of Dhul-Hajjah, he must not take any of his hair and nails until he sacrifices Abu Dawud said: The name of 'Amr b. Muslim in the chain narrated by Malik and Muhammad b. 'Amr is disputed. Some say that it is 'Umar and the majority holds that it is 'Amr. Abu Dawud said: He is 'Amr b. Muslim b. Ukaimah al-Laithi al-Jundu'i}}
\hadithdefcmd{abudawud}{2792}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي حَيْوَةُ، حَدَّثَنِي أَبُو صَخْرٍ، عَنِ ابْنِ قُسَيْطٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِكَبْشٍ أَقْرَنَ يَطَأُ فِي سَوَادٍ وَيَنْظُرُ فِي سَوَادٍ وَيَبْرُكُ فِي سَوَادٍ فَأُتِيَ بِهِ فَضَحَّى بِهِ فَقَالَ ‏"‏ يَا عَائِشَةُ هَلُمِّي الْمُدْيَةَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ اشْحَذِيهَا بِحَجَرٍ ‏"‏ ‏.‏ فَفَعَلَتْ فَأَخَذَهَا وَأَخَذَ الْكَبْشَ فَأَضْجَعَهُ وَذَبَحَهُ وَقَالَ ‏"‏ بِسْمِ اللَّهِ اللَّهُمَّ تَقَبَّلْ مِنْ مُحَمَّدٍ وَآلِ مُحَمَّدٍ وَمِنْ أُمَّةِ مُحَمَّدٍ ‏"‏ ‏.‏ ثُمَّ ضَحَّى بِهِ صلى الله عليه وسلم ‏.‏\hadithno{2792}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim (1967)}\hadithtrans{Narrated 'Aishah:The Prophet (Saws) ordered a horned ram with black legs, black belly and black round the eyes, and it was brought from him to sacrifice. He said: 'Aishah, get the knife then he said: Sharpen it with a stone. So I did. He took it, then take the ram he placed it on the ground and slaughtered it. He then said: In the name of Allah. O Allah, accept it for Muhammad, Muhammad's family and Muhammad's people. Then he sacrificed it}}
\hadithdefcmd{abudawud}{2793}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَحَرَ سَبْعَ بَدَنَاتٍ بِيَدِهِ قِيَامًا وَضَحَّى بِالْمَدِينَةِ بِكَبْشَيْنِ أَقْرَنَيْنِ أَمْلَحَيْنِ ‏.‏\hadithno{2793}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1712)}\hadithtrans{Narrated Anas:The Prophet (ﷺ) sacrificed seven camels standing with his own hand, and sacrificed at Medina two horned rams which were white with black markings}}
\hadithdefcmd{abudawud}{2794}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم ضَحَّى بِكَبْشَيْنِ أَقْرَنَيْنِ أَمْلَحَيْنِ يَذْبَحُ وَيُكَبِّرُ وَيُسَمِّي وَيَضَعُ رِجْلَهُ عَلَى صَفْحَتِهِمَا ‏.‏\hadithno{2794}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3799)}\hadithtrans{Narrated Anas:The Prophet (ﷺ) sacrificed two horned rams which were white with black markings, slaughtered, and uttered: "Allah is Most Great." and mentioned Allah's name and placed his foot on their sides}}
\hadithdefcmd{abudawud}{2795}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، حَدَّثَنَا عِيسَى، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي عَيَّاشٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ ذَبَحَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ الذَّبْحِ كَبْشَيْنِ أَقْرَنَيْنِ أَمْلَحَيْنِ مُوجَأَيْنِ فَلَمَّا وَجَّهَهُمَا قَالَ ‏ "‏ إِنِّي وَجَّهْتُ وَجْهِيَ لِلَّذِي فَطَرَ السَّمَوَاتِ وَالأَرْضَ عَلَى مِلَّةِ إِبْرَاهِيمَ حَنِيفًا وَمَا أَنَا مِنَ الْمُشْرِكِينَ إِنَّ صَلاَتِي وَنُسُكِي وَمَحْيَاىَ وَمَمَاتِي لِلَّهِ رَبِّ الْعَالَمِينَ لاَ شَرِيكَ لَهُ وَبِذَلِكَ أُمِرْتُ وَأَنَا مِنَ الْمُسْلِمِينَ اللَّهُمَّ مِنْكَ وَلَكَ عَنْ مُحَمَّدٍ وَأُمَّتِهِ بِاسْمِ اللَّهِ وَاللَّهُ أَكْبَرُ ‏"‏ ‏.‏ ثُمَّ ذَبَحَ ‏.‏\hadithno{2795}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) sacrificed two horned rams which were white with black markings and had been castrated. When he made them face the qiblah, he said: I have turned my face towards Him. Who created the heavens and the earth, following Abraham's religion, the true in faith, and I am not one of the polytheists. My prayer, and my service of sacrifice, my life and my death are all for Allah, the Lord of the Universe, Who has no partner. That is what I was commanded to do, and I am one of the Muslims. O Allah it comes from Thee and is given to Thee from Muhammad and his people. In the name of Allah, and Allah is Most Great. He then made sacrifice}}
\hadithdefcmd{abudawud}{2796}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا حَفْصٌ، عَنْ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُضَحِّي بِكَبْشٍ أَقْرَنَ فَحِيلٍ يَنْظُرُ فِي سَوَادٍ وَيَأْكُلُ فِي سَوَادٍ وَيَمْشِي فِي سَوَادٍ ‏.‏\hadithno{2796}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Messenger of Allah (ﷺ) used to sacrifice a choice, horned ram with black round the eyes, the mouth and the feet}}
\hadithdefcmd{abudawud}{2797}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَذْبَحُوا إِلاَّ مُسِنَّةً إِلاَّ أَنْ يَعْسُرَ عَلَيْكُمْ فَتَذْبَحُوا جَذَعَةً مِنَ الضَّأْنِ ‏"‏ ‏.‏\hadithno{2797}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih Muslim (1963)}\hadithtrans{Narrated Jabir:The Messenger of Allah (ﷺ) as saying: Sacrifice only a full-grown animal unless it is difficult for you, in which case sacrifice a lamb}}
\hadithdefcmd{abudawud}{2798}{حَدَّثَنَا مُحَمَّدُ بْنُ صُدْرَانَ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، حَدَّثَنِي عُمَارَةُ بْنُ عَبْدِ اللَّهِ بْنِ طُعْمَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي أَصْحَابِهِ ضَحَايَا فَأَعْطَانِي عَتُودًا جَذَعًا - قَالَ - فَرَجَعْتُ بِهِ إِلَيْهِ فَقُلْتُ لَهُ إِنَّهُ جَذَعٌ ‏.‏ قَالَ ‏ "‏ ضَحِّ بِهِ ‏"‏ ‏.‏ فَضَحَّيْتُ بِهِ ‏.‏\hadithno{2798}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Zayd ibn Khalid al-Juhani: The Messenger of Allah (ﷺ) distributed sacrificial animals among his Companions. He gave me a kid (of less than a year). I took it to him and said: This is a kid. He said: Sacrifice it. so I sacrificed it}}
\hadithdefcmd{abudawud}{2799}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا الثَّوْرِيُّ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَجُلٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يُقَالُ لَهُ مُجَاشِعٌ مِنْ بَنِي سُلَيْمٍ فَعَزَّتِ الْغَنَمُ فَأَمَرَ مُنَادِيًا فَنَادَى أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ إِنَّ الْجَذَعَ يُوَفِّي مِمَّا يُوَفِّي مِنْهُ الثَّنِيُّ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ مُجَاشِعُ بْنُ مَسْعُودٍ ‏.‏\hadithno{2799}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Asim b. Kulaib: On the authority of his father: We were with a man from the Companions of the Prophet (ﷺ) called Mujashi' who belonged to Banu Sulaim. There was a scarcity if goats (in those days). He commanded a man to announce (among the people); so he announced that the Messenger of Allah (ﷺ) used to say: A lamb may be given as full payent for that for which has full-grown animal is payment. Abu Dawud said: His name is Mujashi' b. Mas'ud}}
\hadithdefcmd{abudawud}{2800}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا مَنْصُورٌ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ النَّحْرِ بَعْدَ الصَّلاَةِ فَقَالَ ‏"‏ مَنْ صَلَّى صَلاَتَنَا وَنَسَكَ نُسُكَنَا فَقَدْ أَصَابَ النُّسُكَ وَمَنْ نَسَكَ قَبْلَ الصَّلاَةِ فَتِلْكَ شَاةُ لَحْمٍ ‏"‏ ‏.‏ فَقَامَ أَبُو بُرْدَةَ بْنُ نِيَارٍ فَقَالَ يَا رَسُولَ اللَّهِ وَاللَّهِ لَقَدْ نَسَكْتُ قَبْلَ أَنْ أَخْرُجَ إِلَى الصَّلاَةِ وَعَرَفْتُ أَنَّ الْيَوْمَ يَوْمُ أَكْلٍ وَشُرْبٍ فَتَعَجَّلْتُ فَأَكَلْتُ وَأَطْعَمْتُ أَهْلِي وَجِيرَانِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تِلْكَ شَاةُ لَحْمٍ ‏"‏ ‏.‏ فَقَالَ إِنَّ عِنْدِي عَنَاقًا جَذَعَةً وَهِيَ خَيْرٌ مِنْ شَاتَىْ لَحْمٍ فَهَلْ تُجْزِئُ عَنِّي قَالَ ‏"‏ نَعَمْ وَلَنْ تُجْزِئَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏ ‏.‏\hadithno{2800}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (983) Sahih Muslim (1961)}\hadithtrans{Narrated Al-Bara' bin 'Azib:The Messenger of Allah (ﷺ) delivered a sermon to us on the day of sacrifice after the prayer. He said: If anyone prays like our prayer, and sacrifices like our sacrifice, his sacrifice is all right. If anyone sacrifices before the prayer (for 'Id), that is goat meant for flesh. Abu Burdah b. Niyar stood up and said: Messenger of Allah, I swear by Allah, I sacrificed before I went for prayer. I thought it was the day of eating and drinking; so I made haste, and ate myself, and supplied flesh to my family and neighbors. The Messenger of Allah (ﷺ) said: That is a goat meant for eating flesh. He said: I have a kid (of less than a year) which is better than two goats meant for flesh. Will it be valid from me ? He said: Yes, but it will not be valid for anyone after you}}
\hadithdefcmd{abudawud}{2801}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ، عَنْ مُطَرِّفٍ، عَنْ عَامِرٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ ضَحَّى خَالٌ لِي يُقَالُ لَهُ أَبُو بُرْدَةَ قَبْلَ الصَّلاَةِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ شَاتُكَ شَاةُ لَحْمٍ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ عِنْدِي دَاجِنًا جَذَعَةً مِنَ الْمَعْزِ فَقَالَ ‏"‏ اذْبَحْهَا وَلاَ تَصْلُحُ لِغَيْرِكَ ‏"‏ ‏.‏\hadithno{2801}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5556) Sahih Muslim (1961)}\hadithtrans{Narrated Al-Bara' ibn Azib: A maternal uncle of mine called AbuBurdah sacrificed before the prayer (for 'Id). The Messenger of Allah (ﷺ) said: Your goat is meant for flesh. He said: Messenger of Allah, I have a domestic kid with me. He said: Sacrifice it, but it is not valid for any man other than you}}
\hadithdefcmd{abudawud}{2802}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عُبَيْدِ بْنِ فَيْرُوزَ، قَالَ سَأَلْتُ الْبَرَاءَ بْنَ عَازِبٍ مَا لاَ يَجُوزُ فِي الأَضَاحِي فَقَالَ قَامَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصَابِعِي أَقْصَرُ مِنْ أَصَابِعِهِ وَأَنَامِلِي أَقْصَرُ مِنْ أَنَامِلِهِ فَقَالَ ‏"‏ أَرْبَعٌ لاَ تَجُوزُ فِي الأَضَاحِي الْعَوْرَاءُ بَيِّنٌ عَوَرُهَا وَالْمَرِيضَةُ بَيِّنٌ مَرَضُهَا وَالْعَرْجَاءُ بَيِّنٌ ظَلْعُهَا وَالْكَسِيرُ الَّتِي لاَ تَنْقَى ‏"‏ ‏.‏ قَالَ قُلْتُ فَإِنِّي أَكْرَهُ أَنْ يَكُونَ فِي السِّنِّ نَقْصٌ ‏.‏ قَالَ ‏"‏ مَا كَرِهْتَ فَدَعْهُ وَلاَ تُحَرِّمْهُ عَلَى أَحَدٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ لَيْسَ لَهَا مُخٌّ ‏.‏\hadithno{2802}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ubayd ibn Firuz: I asked al-Bara' ibn Azib: What should be avoided in sacrificial animals? He said: The Messenger of Allah (ﷺ) stood among us, and my fingers are smaller than his fingers, and my fingertips are smaller than his fingertips. He said (pointing with his fingers): Four (types of animals) should be avoided in sacrifice: A One-eyed animal which has obviously lost the sight of one eye, a sick animal which is obviously sick, a lame animal which obviously limps and an animal with a broken leg with no marrow. I also detest an animal which has defective teeth. He said: Leave what you detest, but do not make it illegal for anyone. Abu Dawud said: (By a lean animal mean) and animal which has no marrow}}
\hadithdefcmd{abudawud}{2803}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، قَالَ أَخْبَرَنَا ح، وَحَدَّثَنَا عَلِيُّ بْنُ بَحْرِ بْنِ بَرِّيٍّ، حَدَّثَنَا عِيسَى، - الْمَعْنَى - عَنْ ثَوْرٍ، حَدَّثَنِي أَبُو حُمَيْدٍ الرُّعَيْنِيُّ، أَخْبَرَنِي يَزِيدُ، ذُو مِصْرٍ قَالَ أَتَيْتُ عُتْبَةَ بْنَ عَبْدٍ السُّلَمِيَّ فَقُلْتُ يَا أَبَا الْوَلِيدِ إِنِّي خَرَجْتُ أَلْتَمِسُ الضَّحَايَا فَلَمْ أَجِدْ شَيْئًا يُعْجِبُنِي غَيْرَ ثَرْمَاءَ فَكَرِهْتُهَا فَمَا تَقُولُ قَالَ أَفَلاَ جِئْتَنِي بِهَا ‏.‏ قُلْتُ سُبْحَانَ اللَّهِ تَجُوزُ عَنْكَ وَلاَ تَجُوزُ عَنِّي قَالَ نَعَمْ إِنَّكَ تَشُكُّ وَلاَ أَشُكُّ إِنَّمَا نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُصْفَرَّةِ وَالْمُسْتَأْصَلَةِ وَالْبَخْقَاءِ وَالْمُشَيَّعَةِ وَالْكَسْرَاءِ فَالْمُصْفَرَّةُ الَّتِي تُسْتَأْصَلُ أُذُنُهَا حَتَّى يَبْدُوَ سِمَاخُهَا وَالْمُسْتَأْصَلَةُ الَّتِي اسْتُؤْصِلَ قَرْنُهَا مِنْ أَصْلِهِ وَالْبَخْقَاءُ الَّتِي تَبْخَقُ عَيْنُهَا وَالْمُشَيَّعَةُ الَّتِي لاَ تَتْبَعُ الْغَنَمَ عَجْفًا وَضَعْفًا وَالْكَسْرَاءُ الْكَسِيرَةُ ‏.‏\hadithno{2803}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Yazid Dhu Misr : I came to Utbah ibn AbdusSulami and said: AbulWalid, I went out seeking sacrificial animals. I did not find anything which attracted me except an animal whose teeth have fallen. So I abominated it. What do you say (about it)? He said: Why did you not bring it to me? He said: Glory be to Allah: Is if lawful for you and not lawful for me? He said: Yes, you doubt and I do not doubt. The Messenger of Allah (ﷺ) has forbidden an animal whose ear has been uprooted so much so that its hole appears (outwardly), and an animal whose horn has broken from the root, and an animal which has totally lost the sight of its eye, and an animal which is so thin and weak that it cannot go with the herd, and an animal with a broken leg}}
\hadithdefcmd{abudawud}{2804}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ شُرَيْحِ بْنِ النُّعْمَانِ، - وَكَانَ رَجُلَ صِدْقٍ - عَنْ عَلِيٍّ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَسْتَشْرِفَ الْعَيْنَ وَالأُذُنَيْنِ وَلاَ نُضَحِّيَ بِعَوْرَاءَ وَلاَ مُقَابَلَةٍ وَلاَ مُدَابَرَةٍ وَلاَ خَرْقَاءَ وَلاَ شَرْقَاءَ ‏.‏ قَالَ زُهَيْرٌ فَقُلْتُ لأَبِي إِسْحَاقَ أَذَكَرَ عَضْبَاءَ قَالَ لاَ ‏.‏ قُلْتُ فَمَا الْمُقَابَلَةُ قَالَ يُقْطَعُ طَرَفُ الأُذُنِ ‏.‏ قُلْتُ فَمَا الْمُدَابَرَةُ قَالَ يُقْطَعُ مِنْ مُؤَخَّرِ الأُذُنِ ‏.‏ قُلْتُ فَمَا الشَّرْقَاءُ قَالَ تُشَقُّ الأُذُنُ ‏.‏ قُلْتُ فَمَا الْخَرْقَاءُ قَالَ تُخْرَقُ أُذُنُهَا لِلسِّمَةِ ‏.‏\hadithno{2804}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) enjoined upon us to pay great attention to the eye and both ears, and not to sacrifice a one-eyed animal, and an animal with a slit which leaves something hanging at the front or back of the ear, or with a lengthwise slit with a perforation in the ear. I asked AbuIshaq: Did he mention an animal with broken horns and uprooted ears? He said: No. I said: 'What is the Muqabalah ?' He replied: 'It has been cut from the back of its ear.' I said: 'What about the Sharqa'? He replied: 'The ear has been split.' I said: 'What about the Kharqa'? He replied: 'A hole is made (in its ears) as a distinguishing mark}}
\hadithdefcmd{abudawud}{2805}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامُ بْنُ أَبِي عَبْدِ اللَّهِ الدَّسْتَوَائِيُّ، وَيُقَالُ، لَهُ هِشَامُ بْنُ سَنْبَرٍ عَنْ قَتَادَةَ، عَنْ جُرَىِّ بْنِ كُلَيْبٍ، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يُضَحَّى بِعَضْبَاءِ الأُذُنِ وَالْقَرْنِ ‏.‏ قَالَ أَبُو دَاوُدَ جُرَىٌّ سَدُوسِيٌّ بَصْرِيٌّ لَمْ يُحَدِّثْ عَنْهُ إِلاَّ قَتَادَةُ ‏.‏\hadithno{2805}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) prohibited to sacrifice an animal with a slit ear and broken horn. Abu Dawud said: The narrator Jurayy (b. Kulaib) is Sadusi, and belongs to Basrah. No one narrated traditions from him except Qatadah}}
\hadithdefcmd{abudawud}{2806}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، قَالَ قُلْتُ لِسَعِيدِ بْنِ الْمُسَيَّبِ مَا الأَعْضَبُ قَالَ النِّصْفُ فَمَا فَوْقَهُ ‏.‏\hadithno{2806}\hadithgrade{Al-Albani: Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Qatadah:I asked Sa'id b. al-Musayyab: What is meant by animal with a slit ear and broken horn ? He replied: Half and more than half}}
\hadithdefcmd{abudawud}{2807}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا نَتَمَتَّعُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم نَذْبَحُ الْبَقَرَةَ عَنْ سَبْعَةٍ وَالْجَزُورَ عَنْ سَبْعَةٍ نَشْتَرِكُ فِيهَا ‏.‏\hadithno{2807}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1318)}\hadithtrans{Narrated Jabir bin ‘Abdullah :We performed tamattu' during the lifetime of the Messenger of Allah (ﷺ), sacrificed a cow for seven and a camel for seven people. We shared them}}
\hadithdefcmd{abudawud}{2808}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ قَيْسٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَقَرَةُ عَنْ سَبْعَةٍ وَالْجَزُورُ عَنْ سَبْعَةٍ ‏"‏ ‏.‏\hadithno{2808}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: A cow serves for seven, and a camel serves for seven}}
\hadithdefcmd{abudawud}{2809}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ نَحَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْحُدَيْبِيَةِ الْبَدَنَةَ عَنْ سَبْعَةٍ وَالْبَقَرَةَ عَنْ سَبْعَةٍ ‏.‏\hadithno{2809}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1318)}\hadithtrans{Narrated Jabir ibn Abdullah: We sacrificed along with the Messenger of Allah (ﷺ) at al-Hudaybiyyah a camel for seven and a cow for seven people}}
\hadithdefcmd{abudawud}{2810}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي الإِسْكَنْدَرَانِيَّ - عَنْ عَمْرٍو، عَنِ الْمُطَّلِبِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ شَهِدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الأَضْحَى بِالْمُصَلَّى فَلَمَّا قَضَى خُطْبَتَهُ نَزَلَ مِنْ مِنْبَرِهِ وَأُتِيَ بِكَبْشٍ فَذَبَحَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ وَقَالَ ‏ "‏ بِسْمِ اللَّهِ وَاللَّهُ أَكْبَرُ هَذَا عَنِّي وَعَمَّنْ لَمْ يُضَحِّ مِنْ أُمَّتِي ‏"‏ ‏.‏\hadithno{2810}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: I witnessed sacrificing along with the Messenger of Allah (ﷺ) at the place of prayer. When he finished his sermon, he descended from his pulpit, and a ram was brought to him. The Messenger of Allah (ﷺ) slaughtered it with his hand, and said: In the name of Allah, Allah, is Most Great. This is from me and from those who did not sacrifice from my community}}
\hadithdefcmd{abudawud}{2811}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، أَنَّ أَبَا أُسَامَةَ، حَدَّثَهُمْ عَنْ أُسَامَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَذْبَحُ أُضْحِيَتَهُ بِالْمُصَلَّى وَكَانَ ابْنُ عُمَرَ يَفْعَلُهُ ‏.‏\hadithno{2811}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Umar:The Prophet (ﷺ) used to slaughter his sacrificial animal at the place of prayer. Ibn 'Umar used to do so}}
\hadithdefcmd{abudawud}{2812}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، قَالَتْ سَمِعْتُ عَائِشَةَ، تَقُولُ دَفَّ نَاسٌ مِنْ أَهْلِ الْبَادِيَةِ حَضْرَةَ الأَضْحَى فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ادَّخِرُوا الثُّلُثَ وَتَصَدَّقُوا بِمَا بَقِيَ ‏"‏ ‏.‏ قَالَتْ فَلَمَّا كَانَ بَعْدَ ذَلِكَ قِيلَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ لَقَدْ كَانَ النَّاسُ يَنْتَفِعُونَ مِنْ ضَحَايَاهُمْ وَيَجْمُلُونَ مِنْهَا الْوَدْكَ وَيَتَّخِذُونَ مِنْهَا الأَسْقِيَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ أَوْ كَمَا قَالَ قَالُوا يَا رَسُولَ اللَّهِ نَهَيْتَ عَنْ إِمْسَاكِ لُحُومِ الضَّحَايَا بَعْدَ ثَلاَثٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا نَهَيْتُكُمْ مِنْ أَجْلِ الدَّافَّةِ الَّتِي دَفَّتْ عَلَيْكُمْ فَكُلُوا وَتَصَدَّقُوا وَادَّخِرُوا ‏"‏ ‏.‏\hadithno{2812}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1971)}\hadithtrans{Narrated 'Aishah:Some people of desert came at the time of sacrifice in the time of Apostle of Allah (ﷺ). The Messenger of Allah (ﷺ) said: Store up for three days and give the rest as sadaqah (alms). After than the people said to the Messenger of Allah (ﷺ): Messenger of Allah, the people used to benefit from their sacrifices, take and dissolve fat from them, and make water-bags (from their skins). The Messenger of Allah (ﷺ) said: What is that ? or whatever he said: They said: Messenger of Allah (ﷺ), you have prohibited to preserve the meat of sacrifice after three days. The Messenger of Allah (ﷺ) said: I prohibited you due to a body of people who came to you. Now eat, give it as sadaqah (alms), and store up}}
\hadithdefcmd{abudawud}{2813}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي الْمَلِيحِ، عَنْ نُبَيْشَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّا كُنَّا نَهَيْنَاكُمْ عَنْ لُحُومِهَا أَنْ تَأْكُلُوهَا فَوْقَ ثَلاَثٍ لِكَىْ تَسَعَكُمْ فَقَدْ جَاءَ اللَّهُ بِالسَّعَةِ فَكُلُوا وَادَّخِرُوا وَاتَّجِرُوا أَلاَ وَإِنَّ هَذِهِ الأَيَّامَ أَيَّامُ أَكْلٍ وَشُرْبٍ وَذِكْرِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2813}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Nubayshah: The Prophet (ﷺ) said: We forbade you to eat their meat for more than three days in order that you might have abundance; now Allah has produced abundance, so you may eat, store up and seek reward. Beware, these days are days of eating, drinking and remembrance of Allah, Most High}}
\hadithdefcmd{abudawud}{2814}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ الْخَيَّاطُ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ أَبِي الزَّاهِرِيَّةِ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ ثَوْبَانَ، قَالَ ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ يَا ثَوْبَانُ أَصْلِحْ لَنَا لَحْمَ هَذِهِ الشَّاةِ ‏"‏ ‏.‏ قَالَ فَمَا زِلْتُ أُطْعِمُهُ مِنْهَا حَتَّى قَدِمْنَا الْمَدِينَةَ ‏.‏\hadithno{2814}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1975)}\hadithtrans{Narrated Thawban:The Messenger of Allah (ﷺ) sacrificed during a journey and then said: Thawban, mend the meat of this goat. I then kept on supplying its meat until we reached Medina}}
\hadithdefcmd{abudawud}{2815}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ شَدَّادِ بْنِ أَوْسٍ، قَالَ خَصْلَتَانِ سَمِعْتُهُمَا مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ كَتَبَ الإِحْسَانَ عَلَى كُلِّ شَىْءٍ فَإِذَا قَتَلْتُمْ فَأَحْسِنُوا ‏"‏ ‏.‏ قَالَ غَيْرُ مُسْلِمٍ يَقُولُ ‏"‏ فَأَحْسِنُوا الْقِتْلَةَ وَإِذَا ذَبَحْتُمْ فَأَحْسِنُوا الذَّبْحَ وَلْيُحِدَّ أَحَدُكُمْ شَفْرَتَهُ وَلْيُرِحْ ذَبِيحَتَهُ ‏"‏ ‏.‏\hadithno{2815}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1955)}\hadithtrans{Narrated Shaddad b. Aws:There are two characteristics that I heard the Messenger of Allah (ﷺ) say: Allah has decreed that everything should be done in a good way, so when you kill use a good method. The version of the narrators other than Muslim says: "So kill in a good manner." And when you slaughter, you should use a good method, for one of you should sharpen his knife, and give the animal as little pain as possible}}
\hadithdefcmd{abudawud}{2816}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، قَالَ دَخَلْتُ مَعَ أَنَسٍ عَلَى الْحَكَمِ بْنِ أَيُّوبَ فَرَأَى فِتْيَانًا أَوْ غِلْمَانًا قَدْ نَصَبُوا دَجَاجَةً يَرْمُونَهَا فَقَالَ أَنَسٌ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُصْبَرَ الْبَهَائِمُ ‏.‏\hadithno{2816}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5513) Sahih Muslim (1956)}\hadithtrans{Narrated Hisham b. Zaid:I entered upon al-Hakam b. Ayyub along with Anas. He saw some youths or boys who had set up a hen and shooting at it. Anas said: The Messenger of Allah (ﷺ) forbade to kill an animal in confinement}}
\hadithdefcmd{abudawud}{2817}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ فَكُلُوا مِمَّا ذُكِرَ اسْمُ اللَّهِ عَلَيْهِ ‏\}‏ ‏\{‏ وَلاَ تَأْكُلُوا مِمَّا لَمْ يُذْكَرِ اسْمُ اللَّهِ عَلَيْهِ ‏\}‏ فَنُسِخَ وَاسْتَثْنَى مِنْ ذَلِكَ فَقَالَ ‏\{‏ وَطَعَامُ الَّذِينَ أُوتُوا الْكِتَابَ حِلٌّ لَكُمْ وَطَعَامُكُمْ حِلٌّ لَهُمْ ‏\}‏ ‏.‏\hadithno{2817}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas:The verse: "So eat of (meats) on which Allah's name hath been pronounced" and the verse: "Eat not of (meats) on which Allah's name hath not been pronounced" were abrogated, meaning an exception was made therein by the verse: "The food of the people of the Book is lawful unto you and yours is lawful unto them}}
\hadithdefcmd{abudawud}{2818}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا إِسْرَائِيلُ، حَدَّثَنَا سِمَاكٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ ‏\{‏ وَإِنَّ الشَّيَاطِينَ لَيُوحُونَ إِلَى أَوْلِيَائِهِمْ ‏\}‏ يَقُولُونَ مَا ذَبَحَ اللَّهُ فَلاَ تَأْكُلُوا وَمَا ذَبَحْتُمْ أَنْتُمْ فَكُلُوا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تَأْكُلُوا مِمَّا لَمْ يُذْكَرِ اسْمُ اللَّهِ عَلَيْهِ ‏\}‏ ‏.‏\hadithno{2818}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: explaining the verse "But the evil ones ever inspire their friend to contend with you" They used to say: Do not eat which Allah killed, but eat which you slaughtered. So Allah revealed the verse: "Eat not of (meats) on which Allah's name hath not been pronounced"...to the end of the verse}}
\hadithdefcmd{abudawud}{2819}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عِمْرَانُ بْنُ عُيَيْنَةَ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَتِ الْيَهُودُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالُوا نَأْكُلُ مِمَّا قَتَلْنَا وَلاَ نَأْكُلُ مِمَّا قَتَلَ اللَّهُ فَأَنْزَلَ اللَّهُ ‏\{‏ وَلاَ تَأْكُلُوا مِمَّا لَمْ يُذْكَرِ اسْمُ اللَّهِ عَلَيْهِ ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{2819}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Jews came to the Prophet (ﷺ) and said: We eat which we kill but we do not eat which Allah kills? So Allah revealed: "Eat not of (meats) on which Allah's name hath not been pronounced." to the end of the verse}}
\hadithdefcmd{abudawud}{2820}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، عَنْ عَوْفٍ، عَنْ أَبِي رَيْحَانَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ مُعَاقَرَةِ الأَعْرَابِ ‏.‏ قَالَ أَبُو دَاوُدَ اسْمُ أَبِي رَيْحَانَةَ عَبْدُ اللَّهِ بْنُ مَطَرٍ وَغُنْدَرٌ أَوْقَفَهُ عَلَى ابْنِ عَبَّاسٍ ‏.‏\hadithno{2820}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) forbade to eat (the meat of animals) slaughtered by the bedouins for vainglory and pride. Abu Dawud said: The narrator Ghundar narrated this tradition as a saying of Ibn 'Abbas (and not of the Prophet)}}
\hadithdefcmd{abudawud}{2821}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا سَعِيدُ بْنُ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا نَلْقَى الْعَدُوَّ غَدًا وَلَيْسَ مَعَنَا مُدًى أَفَنَذْبَحُ بِالْمَرْوَةِ وَشِقَّةِ الْعَصَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرِنْ أَوْ أَعْجِلْ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ عَلَيْهِ فَكُلُوا مَا لَمْ يَكُنْ سِنًّا أَوْ ظُفْرًا وَسَأُحَدِّثُكُمْ عَنْ ذَلِكَ أَمَّا السِّنُّ فَعَظْمٌ وَأَمَّا الظُّفْرُ فَمُدَى الْحَبَشَةِ ‏"‏ ‏.‏ وَتَقَدَّمَ بِهِ سَرَعَانٌ مِنَ النَّاسِ فَتَعَجَّلُوا فَأَصَابُوا مِنَ الْغَنَائِمِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي آخِرِ النَّاسِ فَنَصَبُوا قُدُورًا فَمَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْقُدُورِ فَأَمَرَ بِهَا فَأُكْفِئَتْ وَقَسَمَ بَيْنَهُمْ فَعَدَلَ بَعِيرًا بِعَشْرِ شِيَاهٍ وَنَدَّ بَعِيرٌ مِنْ إِبِلِ الْقَوْمِ وَلَمْ يَكُنْ مَعَهُمْ خَيْلٌ فَرَمَاهُ رَجُلٌ بِسَهْمٍ فَحَبَسَهُ اللَّهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ لِهَذِهِ الْبَهَائِمِ أَوَابِدَ كَأَوَابِدِ الْوَحْشِ فَمَا فَعَلَ مِنْهَا هَذَا فَافْعَلُوا بِهِ مِثْلَ هَذَا ‏"‏ ‏.‏\hadithno{2821}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5498) Sahih Muslim (1968)}\hadithtrans{Narrated Rafi' b. Khadij:I came to the Messenger of Allah (ﷺ) and said: Messenger of Allah, we shall meet the enemy tomorrow and we have no knives with us. May we kill with a sharp-edged white stone (flint) and with splinter of a staff ? The Messenger of Allah (ﷺ) said: Hasten in slaughtering it. When Allah's name is mentioned you may eat what is killed by anything which causes the blood to flow except tooth and claw. I shall tell you about it. The tooth is a bone, and the claw is the knife of Abyssinians. Some people hastened and went forward, they made haste and got booty, while the Messenger of Allah (ﷺ) was in the rear and they setup cooking pots. The Messenger of Allah (ﷺ) passed by over the cooking pots. He ordered to turn them over. He then divided (the spoils of war) between them, and gave them a camel for ten goats in equation. One of the camels of the people ran away, and they had no horses with them at that time. A man shot an arrow at it, and Allah prevented it from escaping. The Prophet (ﷺ) said: Among animals (i.e. camels) there are some which bolt like wild animals ; so when any of them does so, do with it like this}}
\hadithdefcmd{abudawud}{2822}{حَدَّثَنَا مُسَدَّدٌ، أَنَّ عَبْدَ الْوَاحِدِ بْنَ زِيَادٍ، وَحَمَّادًا، حَدَّثَاهُمْ - الْمَعْنَى، وَاحِدٌ، - عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنْ مُحَمَّدِ بْنِ صَفْوَانَ، أَوْ صَفْوَانَ بْنِ مُحَمَّدٍ قَالَ اصَّدْتُ أَرْنَبَيْنِ فَذَبَحْتُهُمَا بِمَرْوَةٍ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْهُمَا فَأَمَرَنِي بِأَكْلِهِمَا ‏.‏\hadithno{2822}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Muhammad ibn Safwan or Safwan ibn Muhammad: I hunted two hares and slaughtered them with a flint. I asked the Messenger of Allah (ﷺ) about them. He permitted me to eat them}}
\hadithdefcmd{abudawud}{2823}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ رَجُلٍ، مِنْ بَنِي حَارِثَةَ أَنَّهُ كَانَ يَرْعَى لِقْحَةً بِشِعْبٍ مِنْ شِعَابِ أُحُدٍ فَأَخَذَهَا الْمَوْتُ فَلَمْ يَجِدْ شَيْئًا يَنْحَرُهَا بِهِ فَأَخَذَ وَتَدًا فَوَجَأَ بِهِ فِي لَبَّتِهَا حَتَّى أُهْرِيقَ دَمُهَا ثُمَّ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ بِذَلِكَ فَأَمَرَهُ بِأَكْلِهَا ‏.‏\hadithno{2823}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ata' ibn Yasar: A man of Banu Harith was pasturing a pregnant she-camel in one of the ravines of Uhud, (he saw that) it was about to die; he could find nothing to slaughter it; he took a stake and stabbed it in the upper part of its breast until he made its blood flow. He then came to the Prophet (ﷺ) and informed him about that, and he ordered him to eat it}}
\hadithdefcmd{abudawud}{2824}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ مُرِّيِّ بْنِ قَطَرِيٍّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ أَحَدُنَا أَصَابَ صَيْدًا وَلَيْسَ مَعَهُ سِكِّينٌ أَيَذْبَحُ بِالْمَرْوَةِ وَشِقَّةِ الْعَصَا فَقَالَ ‏ "‏ أَمْرِرِ الدَّمَ بِمَا شِئْتَ وَاذْكُرِ اسْمَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2824}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Adi ibn Hatim: I said: Messenger of Allah, tell me when one of us catches game and has no knife; may he slaughter with a flint and a splinter of stick. He said: Cause the blood to flow with whatever you like and mention Allah's name}}
\hadithdefcmd{abudawud}{2825}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي الْعُشَرَاءِ، عَنْ أَبِيهِ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ أَمَا تَكُونُ الذَّكَاةُ إِلاَّ مِنَ اللَّبَّةِ أَوِ الْحَلْقِ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ طَعَنْتَ فِي فَخِذِهَا لأَجْزَأَ عَنْكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا لاَ يَصْلُحُ إِلاَّ فِي الْمُتَرَدِّيَةِ وَالْمُتَوَحِّشِ ‏.‏\hadithno{2825}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbulUshara': AbulUshara' reported on the authority of his father: He asked: Messenger of Allah, is the slaughtering to be done only in the upper part of the breast and the throat? The Messenger of Allah (ﷺ) replied: If you pierced its thigh, it would serve you. Abu Dawud said: This is the way suitable for slaughtering an animal which has fallen into a well or runs loose}}
\hadithdefcmd{abudawud}{2826}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، وَالْحَسَنُ بْنُ عِيسَى، مَوْلَى ابْنِ الْمُبَارَكِ عَنِ ابْنِ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ عَمْرِو بْنِ عَبْدِ اللَّهِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، - زَادَ ابْنُ عِيسَى - وَأَبِي هُرَيْرَةَ قَالاَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ شَرِيطَةِ الشَّيْطَانِ ‏.‏ زَادَ ابْنُ عِيسَى فِي حَدِيثِهِ وَهِيَ الَّتِي تُذْبَحُ فَيُقْطَعُ الْجِلْدُ وَلاَ تُفْرَى الأَوْدَاجُ ثُمَّ تُتْرَكُ حَتَّى تَمُوتَ ‏.‏\hadithno{2826}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: Ibn Isa added: (Ibn Abbas) and AbuHurayrah said: The Messenger of Allah (ﷺ) forbade the devil's sacrifice. AbuIsa added in his version: This refers to the slaughtered animal whose skin cut off, and is then left to die without its jugular veins being severed}}
\hadithdefcmd{abudawud}{2827}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا هُشَيْمٌ، عَنْ مُجَالِدٍ، عَنْ أَبِي الْوَدَّاكِ، عَنْ أَبِي سَعِيدٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْجَنِينِ فَقَالَ ‏"‏ كُلُوهُ إِنْ شِئْتُمْ ‏"‏ ‏.‏ وَقَالَ مُسَدَّدٌ قُلْنَا يَا رَسُولَ اللَّهِ نَنْحَرُ النَّاقَةَ وَنَذْبَحُ الْبَقَرَةَ وَالشَّاةَ فَنَجِدُ فِي بَطْنِهَا الْجَنِينَ أَنُلْقِيهِ أَمْ نَأْكُلُهُ قَالَ ‏"‏ كُلُوهُ إِنْ شِئْتُمْ فَإِنَّ ذَكَاتَهُ ذَكَاةُ أُمِّهِ ‏"‏ ‏.‏\hadithno{2827}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: I asked the Messenger of Allah (ﷺ) about the embryo. He replied: Eat it if you wish. Musaddad's version says: we said: Messenger of Allah, we slaughter a she-camel, a cow and a sheep, and we find an embryo in its womb. Shall we throw it away or eat it? He replied: Eat it if you wish for the slaughter of its mother serves its slaughter}}
\hadithdefcmd{abudawud}{2828}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ رَاهَوَيْهِ، حَدَّثَنَا عَتَّابُ بْنُ بَشِيرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي زِيَادٍ الْقَدَّاحُ الْمَكِّيُّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ ذَكَاةُ الْجَنِينِ ذَكَاةُ أُمِّهِ ‏"‏ ‏.‏\hadithno{2828}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: The slaughter of embryo is included when its mother is slaughtered}}
\hadithdefcmd{abudawud}{2829}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا سُلَيْمَانُ بْنُ حَيَّانَ، وَمُحَاضِرٌ، - الْمَعْنَى - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، وَلَمْ يَذْكُرَا عَنْ حَمَّادٍ، وَمَالِكٍ، عَنْ عَائِشَةَ، أَنَّهُمْ قَالُوا يَا رَسُولَ اللَّهِ إِنَّ قَوْمًا حَدِيثُو عَهْدٍ بِالْجَاهِلِيَّةِ يَأْتُونَنَا بِلُحْمَانٍ لاَ نَدْرِي أَذَكَرُوا اسْمَ اللَّهِ عَلَيْهَا أَمْ لَمْ يَذْكُرُوا أَفَنَأْكُلُ مِنْهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَمُّوا اللَّهَ وَكُلُوا ‏"‏ ‏.‏\hadithno{2829}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:(the narrator Musa did not mention the words "from 'Aishah" in his version from Hammad, and al-Qa'nabi also did not mention the word "from 'Aishah" in his version from Malik). They (the people) said: Messenger of Allah, there are people here, recent converts from polytheism, who bring us meat and we do not know whether or not they mentioned Allah's name over it. The Messenger of Allah (ﷺ) said: Mention Allah's name and eat}}
\hadithdefcmd{abudawud}{2830}{حَدَّثَنَا مُسَدَّدٌ، ح وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، عَنْ بِشْرِ بْنِ الْمُفَضَّلِ، - الْمَعْنَى - حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمَلِيحِ، قَالَ قَالَ نُبَيْشَةُ نَادَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم إِنَّا كُنَّا نَعْتِرُ عَتِيرَةً فِي الْجَاهِلِيَّةِ فِي رَجَبٍ فَمَا تَأْمُرُنَا قَالَ ‏"‏ اذْبَحُوا لِلَّهِ فِي أَىِّ شَهْرٍ كَانَ وَبَرُّوا اللَّهَ عَزَّ وَجَلَّ وَأَطْعِمُوا ‏"‏ ‏.‏ قَالَ إِنَّا كُنَّا نُفْرِعُ فَرَعًا فِي الْجَاهِلِيَّةِ فَمَا تَأْمُرُنَا قَالَ ‏"‏ فِي كُلِّ سَائِمَةٍ فَرَعٌ تَغْذُوهُ مَاشِيَتُكَ حَتَّى إِذَا اسْتَحْمَلَ ‏"‏ ‏.‏ قَالَ نَصْرٌ ‏"‏ اسْتَحْمَلَ لِلْحَجِيجِ ذَبَحْتَهُ فَتَصَدَّقْتَ بِلَحْمِهِ ‏"‏ ‏.‏ قَالَ خَالِدٌ أَحْسَبُهُ قَالَ ‏"‏ عَلَى ابْنِ السَّبِيلِ فَإِنَّ ذَلِكَ خَيْرٌ ‏"‏ ‏.‏ قَالَ خَالِدٌ قُلْتُ لأَبِي قِلاَبَةَ كَمِ السَّائِمَةُ قَالَ مِائَةٌ ‏.‏\hadithno{2830}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Nubayshah: A man called the Messenger of Allah (ﷺ): We used to sacrifice Atirah in pre-Islamic days during Rajab; so what do you command us? He said: Sacrifice for the sake of Allah in any month whatever; obey Allah, Most High, and feed(the people). He said: We used to sacrifice a Fara' in pre-Islamic days, so what do you command us? He said: On every pasturing animal there is a Fara' which is fed by your cattle till it becomes strong and capable of carrying load. The narrator Nasr said (in his version): When it becomes capable of carrying load of the pilgrims, you may slaughter it and give its meat as charity (sadaqah). The narrator Khalid's version says: You (may give it) to the travellers, for it is better. Khalid said: I asked AbuQilabah: How many pasturing animals? He replied: One hundred}}
\hadithdefcmd{abudawud}{2831}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَخْبَرَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ فَرَعَ وَلاَ عَتِيرَةَ ‏"‏ ‏.‏\hadithno{2831}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5474) Sahih Muslim (1976)}\hadithtrans{Narrated Abu Hurairah:Prophet (ﷺ) sa saying: There is no fara' and 'atirah}}
\hadithdefcmd{abudawud}{2832}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، قَالَ الْفَرَعُ أَوَّلُ النِّتَاجِ كَانَ يُنْتَجُ لَهُمْ فَيَذْبَحُونَهُ ‏.‏\hadithno{2832}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'id:Fara' was the first animal born to them (the Arabs) which they sacrificed}}
\hadithdefcmd{abudawud}{2833}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ حَفْصَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ كُلِّ خَمْسِينَ شَاةً شَاةٌ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ بَعْضُهُمُ الْفَرَعُ أَوَّلُ مَا تُنْتَجُ الإِبِلُ كَانُوا يَذْبَحُونَهُ لِطَوَاغِيتِهِمْ ثُمَّ يَأْكُلُونَهُ وَيُلْقَى جِلْدُهُ عَلَى الشَّجَرِ وَالْعَتِيرَةُ فِي الْعَشْرِ الأُوَلِ مِنْ رَجَبٍ ‏.‏\hadithno{2833}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah: The Messenger of Allah (ﷺ) used to sacrifice goat out of every fifty goats. Abu Dawud said: Fara' means the first baby camel born (to the Arabs). They used to sacrifice it for their idols, and then eat it, and its skin was thrown on a tree. 'Atira was a sacrifice made during the first ten days of Rajab}}
\hadithdefcmd{abudawud}{2834}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءٍ، عَنْ حَبِيبَةَ بِنْتِ مَيْسَرَةَ، عَنْ أُمِّ كُرْزٍ الْكَعْبِيَّةِ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ عَنِ الْغُلاَمِ شَاتَانِ مُكَافِئَتَانِ وَعَنِ الْجَارِيَةِ شَاةٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ قَالَ مُكَافِئَتَانِ أَىْ مُسْتَوِيَتَانِ أَوْ مُقَارِبَتَانِ ‏.‏\hadithno{2834}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Umm Kurz al-Ka'biyyah: I heard the Messenger of Allah (ﷺ) say: Two resembling sheep are to be sacrificed for a boy and one for a girl. AbuDawud said: I heard Ahmad (ibn Hanbal) say: The Arabic word mukafi'atani means equal (in age) or resembling each other}}
\hadithdefcmd{abudawud}{2835}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ أَبِيهِ، عَنْ سِبَاعِ بْنِ ثَابِتٍ، عَنْ أُمِّ كُرْزٍ، قَالَتْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ أَقِرُّوا الطَّيْرَ عَلَى مَكِنَاتِهَا ‏"‏ ‏.‏ قَالَتْ وَسَمِعْتُهُ يَقُولُ ‏"‏ عَنِ الْغُلاَمِ شَاتَانِ وَعَنِ الْجَارِيَةِ شَاةٌ لاَ يَضُرُّكُمْ أَذُكْرَانًا كُنَّ أَمْ إِنَاثًا ‏"‏ ‏.‏\hadithno{2835}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Kurz: I heard the Prophet (nay peace be upon him) say: Let the birds stay in their roosts. She said: I also heard him say: Two sheep are to be sacrificed for a boy and one for a girl, but it does you no harm whether they are male or female}}
\hadithdefcmd{abudawud}{2836}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ سِبَاعِ بْنِ ثَابِتٍ، عَنْ أُمِّ كُرْزٍ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَنِ الْغُلاَمِ شَاتَانِ مِثْلاَنِ وَعَنِ الْجَارِيَةِ شَاةٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا هُوَ الْحَدِيثُ وَحَدِيثُ سُفْيَانَ وَهَمٌ ‏.‏\hadithno{2836}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Kurz: The Messenger of Allah (ﷺ) said: Two sheep which resemble each other are to be sacrificed for a boy and one for a girl. Abu Dawud said: This is a sound tradition, and the tradition narrated by Sufyan is misunderstanding}}
\hadithdefcmd{abudawud}{2837}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ كُلُّ غُلاَمٍ رَهِينَةٌ بِعَقِيقَتِهِ تُذْبَحُ عَنْهُ يَوْمَ السَّابِعِ وَيُحْلَقُ رَأْسُهُ وَيُدَمَّى ‏"‏ ‏.‏ فَكَانَ قَتَادَةُ إِذَا سُئِلَ عَنِ الدَّمِ كَيْفَ يُصْنَعُ بِهِ قَالَ إِذَا ذَبَحْتَ الْعَقِيقَةَ أَخَذْتَ مِنْهَا صُوفَةً وَاسْتَقْبَلْتَ بِهِ أَوْدَاجَهَا ثُمَّ تُوضَعُ عَلَى يَافُوخِ الصَّبِيِّ حَتَّى يَسِيلَ عَلَى رَأْسِهِ مِثْلُ الْخَيْطِ ثُمَّ يُغْسَلُ رَأْسُهُ بَعْدُ وَيُحْلَقُ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا وَهَمٌ مِنْ هَمَّامٍ ‏"‏ وَيُدَمَّى ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ خُولِفَ هَمَّامٌ فِي هَذَا الْكَلاَمِ وَهُوَ وَهَمٌ مِنْ هَمَّامٍ وَإِنَّمَا قَالُوا ‏"‏ يُسَمَّى ‏"‏ ‏.‏ فَقَالَ هَمَّامٌ ‏"‏ يُدَمَّى ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَيْسَ يُؤْخَذُ بِهَذَا ‏.‏\hadithno{2837}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah ibn Jundub: The Prophet (ﷺ) said: A boy is in pledge for his Aqiqah. Sacrifice is made for him on the seventh day, his head is shaved and is smeared with blood. When Qatadah was asked about smearing with blood, how that should be done, he said: When you cut the head (i.e. throat) of the animal (meant for Aqiqah), you may take a few hair of it, place them on its veins, and then place them in the middle of the head of the infant, so that the blood flows on the hair (of the infant) like a threat. Then its head may be washed and shaved off. Abu Dawud said: In narrating the word "is smeared with blood" (yudamma) there is a misunderstanding on the part of Hammam. Abu Dawud said: Hammam has been opposed in narrating the words "is smeared with blood". This is misunderstanding of Hammam. They narrated he word "he is given a name (yusamma) and Hammam narrated it "is smeared with blood" (yudamma). Abu Dawud said: This tradition is not followed}}
\hadithdefcmd{abudawud}{2838}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ كُلُّ غُلاَمٍ رَهِينَةٌ بِعَقِيقَتِهِ تُذْبَحُ عَنْهُ يَوْمَ سَابِعِهِ وَيُحْلَقُ وَيُسَمَّى ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَيُسَمَّى أَصَحُّ كَذَا قَالَ سَلاَّمُ بْنُ أَبِي مُطِيعٍ عَنْ قَتَادَةَ وَإِيَاسُ بْنُ دَغْفَلٍ وَأَشْعَثُ عَنِ الْحَسَنِ ‏.‏ قَالَ ‏"‏ وَيُسَمَّى ‏"‏ ‏.‏ وَرَوَاهُ أَشْعَثُ عَنِ الْحَسَنِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ وَيُسَمَّى ‏"‏ ‏.‏\hadithno{2838}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Samurah ibn Jundub: The Prophet (ﷺ) said: A boy is in pledge for his Aqiqah, Sacrifice is made for him on the seventh day, his head is shaved and he is given name. Abu Dawud said: The word wa yusamma is sounder as narrated by Salam b. Abi Muti' from Qatadah, and narrated by Iyas b. Daghfal and Ash'ath from al-Hassan who narrated wa yusamma (and he is given a name)}}
\hadithdefcmd{abudawud}{2839}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنِ الرَّبَابِ، عَنْ سَلْمَانَ بْنِ عَامِرٍ الضَّبِّيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَعَ الْغُلاَمِ عَقِيقَتُهُ فَأَهْرِيقُوا عَنْهُ دَمًا وَأَمِيطُوا عَنْهُ الأَذَى ‏"‏ ‏.‏\hadithno{2839}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5471، 5472)}\hadithtrans{Narrated Salman b. 'Amir al-Dabbi:The Messenger of Allah (ﷺ) as saying: Along with a boy there is an 'Aqiqah, so shed blood on his behalf, and remove injury from him}}
\hadithdefcmd{abudawud}{2840}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامٌ، عَنِ الْحَسَنِ، أَنَّهُ كَانَ يَقُولُ إِمَاطَةُ الأَذَى حَلْقُ الرَّأْسِ ‏.‏\hadithno{2840}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Hasan:To remove the injury is the shaving of the head}}
\hadithdefcmd{abudawud}{2841}{حَدَّثَنَا أَبُو مَعْمَرٍ عَبْدُ اللَّهِ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَقَّ عَنِ الْحَسَنِ وَالْحُسَيْنِ كَبْشًا كَبْشًا ‏.‏\hadithno{2841}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) sacrificed a ram for both al-Hasan and al-Husayn each (Allah be pleased with them)}}
\hadithdefcmd{abudawud}{2842}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم ح وَحَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ حَدَّثَنَا عَبْدُ الْمَلِكِ - يَعْنِي ابْنَ عَمْرٍو - عَنْ دَاوُدَ عَنْ عَمْرِو بْنِ شُعَيْبٍ عَنْ أَبِيهِ أُرَاهُ عَنْ جَدِّهِ قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْعَقِيقَةِ فَقَالَ ‏"‏ لاَ يُحِبُّ اللَّهُ الْعُقُوقَ ‏"‏ ‏.‏ كَأَنَّهُ كَرِهَ الاِسْمَ وَقَالَ ‏"‏ مَنْ وُلِدَ لَهُ وَلَدٌ فَأَحَبَّ أَنْ يَنْسُكَ عَنْهُ فَلْيَنْسُكْ عَنِ الْغُلاَمِ شَاتَانِ مُكَافِئَتَانِ وَعَنِ الْجَارِيَةِ شَاةٌ ‏"‏ ‏.‏ وَسُئِلَ عَنِ الْفَرَعِ قَالَ ‏"‏ وَالْفَرَعُ حَقٌّ وَأَنْ تَتْرُكُوهُ حَتَّى يَكُونَ بَكْرًا شُغْزُبًّا ابْنَ مَخَاضٍ أَوِ ابْنَ لَبُونٍ فَتُعْطِيَهُ أَرْمَلَةً أَوْ تَحْمِلَ عَلَيْهِ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنْ أَنْ تَذْبَحَهُ فَيَلْزَقَ لَحْمُهُ بِوَبَرِهِ وَتُكْفِئَ إِنَاءَكَ وَتُوَلِّهَ نَاقَتَكَ ‏"‏ ‏.‏\hadithno{2842}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather that the Messenger of Allah (ﷺ) was asked about the aqiqah. He replied: Allah does not like the breaking of ties (uquq), as though he disliked the name. And he said: If anyone has a child born to him and wishes to offer a sacrifice on its behalf, he may offer two resembling sheep for a boy and one for a girl. And he was asked about fara'. He replied: Fara' is right. If you leave it (i.e. let it grow till it becomes a healthy camel of one year or two years, then you give it to a widow or give it in the path of Allah for using it as a riding beast, it is better than slaughtering it at the age when its meat is stuck to its hair, and you turn over your milking vessel and annoy your she-camel)}}
\hadithdefcmd{abudawud}{2843}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ، حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ، حَدَّثَنِي أَبِي، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، قَالَ سَمِعْتُ أَبِي بُرَيْدَةَ، يَقُولُ كُنَّا فِي الْجَاهِلِيَّةِ إِذَا وُلِدَ لأَحَدِنَا غُلاَمٌ ذَبَحَ شَاةً وَلَطَخَ رَأْسَهُ بِدَمِهَا فَلَمَّا جَاءَ اللَّهُ بِالإِسْلاَمِ كُنَّا نَذْبَحُ شَاةً وَنَحْلِقُ رَأْسَهُ وَنَلْطَخُهُ بِزَعْفَرَانٍ ‏.‏\hadithno{2843}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Buraydah ibn al-Hasib: When a boy was born to one of us in the pre-Islamic period, we sacrificed a sheep and smeared his head with its blood; but when Allah brought Islam, we sacrificed a sheep, shaved his head and smeared his head with saffron}}
